From c0e4f52e8fecf74bc26ba813522aa96300bb844e Mon Sep 17 00:00:00 2001
From: Dean Camera <dean@fourwalledcubicle.com>
Date: Tue, 28 Sep 2010 14:59:16 +0000
Subject: [PATCH] Fix up incorrect version numbers in demo/project descriptors.

Add class name prefixes to missed constants in the class drivers to give all class driver elements a consistent namespace.
---
 .../ClassDriver/AudioInput/Descriptors.c      |  6 +-
 .../ClassDriver/AudioOutput/Descriptors.c     |  8 +-
 .../Device/Incomplete/Sideshow/Descriptors.c  |  2 +-
 .../TestAndMeasurement/Descriptors.c          |  2 +-
 .../Device/LowLevel/AudioInput/Descriptors.c  |  4 +-
 .../Device/LowLevel/AudioOutput/Descriptors.c |  2 +-
 Demos/Device/LowLevel/MIDI/Descriptors.c      |  2 +-
 Demos/Device/LowLevel/MIDI/Descriptors.h      |  2 +-
 Demos/Device/LowLevel/Mouse/Descriptors.c     |  2 +-
 LUFA/Drivers/USB/Class/Common/Audio.h         | 88 +++++++++----------
 LUFA/Drivers/USB/Class/Common/RNDIS.h         |  9 +-
 LUFA/Drivers/USB/Class/Device/RNDIS.c         |  2 +-
 LUFA/Drivers/USB/Class/Host/CDC.h             |  4 +-
 LUFA/Drivers/USB/Class/Host/HID.h             |  4 +-
 LUFA/Drivers/USB/Class/Host/MIDI.h            |  4 +-
 LUFA/Drivers/USB/Class/Host/MassStorage.h     |  4 +-
 LUFA/Drivers/USB/Class/Host/Printer.h         |  4 +-
 LUFA/Drivers/USB/Class/Host/RNDIS.h           |  4 +-
 LUFA/Drivers/USB/Class/Host/StillImage.h      |  4 +-
 19 files changed, 80 insertions(+), 77 deletions(-)

diff --git a/Demos/Device/ClassDriver/AudioInput/Descriptors.c b/Demos/Device/ClassDriver/AudioInput/Descriptors.c
index 991b33e30..b89c97f73 100644
--- a/Demos/Device/ClassDriver/AudioInput/Descriptors.c
+++ b/Demos/Device/ClassDriver/AudioInput/Descriptors.c
@@ -122,7 +122,7 @@ USB_Descriptor_Configuration_t PROGMEM ConfigurationDescriptor =
 			.Subtype                  = AUDIO_DSUBTYPE_CSInterface_InputTerminal,
 
 			.TerminalID               = 0x01,
-			.TerminalType             = TERMINAL_IN_MIC,
+			.TerminalType             = AUDIO_TERMINAL_IN_MIC,
 			.AssociatedOutputTerminal = 0x00,
 
 			.TotalChannels            = 1,
@@ -138,7 +138,7 @@ USB_Descriptor_Configuration_t PROGMEM ConfigurationDescriptor =
 			.Subtype                  = AUDIO_DSUBTYPE_CSInterface_OutputTerminal,
 
 			.TerminalID               = 0x02,
-			.TerminalType             = TERMINAL_STREAMING,
+			.TerminalType             = AUDIO_TERMINAL_STREAMING,
 			.AssociatedInputTerminal  = 0x00,
 
 			.SourceID                 = 0x01,
@@ -225,7 +225,7 @@ USB_Descriptor_Configuration_t PROGMEM ConfigurationDescriptor =
 			.Header                   = {.Size = sizeof(USB_Audio_Descriptor_StreamEndpoint_Spc_t), .Type = DTYPE_CSEndpoint},
 			.Subtype                  = AUDIO_DSUBTYPE_CSEndpoint_General,
 			
-			.Attributes               = 0x00,
+			.Attributes               = AUDIO_EP_ACCEPTS_SMALL_PACKETS,
 			
 			.LockDelayUnits           = 0x00,
 			.LockDelay                = 0x0000
diff --git a/Demos/Device/ClassDriver/AudioOutput/Descriptors.c b/Demos/Device/ClassDriver/AudioOutput/Descriptors.c
index 57668f2df..7db75609d 100644
--- a/Demos/Device/ClassDriver/AudioOutput/Descriptors.c
+++ b/Demos/Device/ClassDriver/AudioOutput/Descriptors.c
@@ -122,11 +122,11 @@ USB_Descriptor_Configuration_t PROGMEM ConfigurationDescriptor =
 			.Subtype                  = AUDIO_DSUBTYPE_CSInterface_InputTerminal,
 		
 			.TerminalID               = 0x01,
-			.TerminalType             = TERMINAL_STREAMING,
+			.TerminalType             = AUDIO_TERMINAL_STREAMING,
 			.AssociatedOutputTerminal = 0x00,
 			
 			.TotalChannels            = 2,
-			.ChannelConfig            = (CHANNEL_LEFT_FRONT | CHANNEL_RIGHT_FRONT),
+			.ChannelConfig            = (AUDIO_CHANNEL_LEFT_FRONT | AUDIO_CHANNEL_RIGHT_FRONT),
 			
 			.ChannelStrIndex          = NO_DESCRIPTOR,
 			.TerminalStrIndex         = NO_DESCRIPTOR
@@ -138,7 +138,7 @@ USB_Descriptor_Configuration_t PROGMEM ConfigurationDescriptor =
 			.Subtype                  = AUDIO_DSUBTYPE_CSInterface_OutputTerminal,
 		
 			.TerminalID               = 0x02,
-			.TerminalType             = TERMINAL_OUT_SPEAKER,
+			.TerminalType             = AUDIO_TERMINAL_OUT_SPEAKER,
 			.AssociatedInputTerminal  = 0x00,
 			
 			.SourceID                 = 0x01,
@@ -225,7 +225,7 @@ USB_Descriptor_Configuration_t PROGMEM ConfigurationDescriptor =
 			.Header                   = {.Size = sizeof(USB_Audio_Descriptor_StreamEndpoint_Spc_t), .Type = DTYPE_CSEndpoint},
 			.Subtype                  = AUDIO_DSUBTYPE_CSEndpoint_General,
 			
-			.Attributes               = EP_ACCEPTS_SMALL_PACKETS,
+			.Attributes               = AUDIO_EP_ACCEPTS_SMALL_PACKETS,
 			
 			.LockDelayUnits           = 0x00,
 			.LockDelay                = 0x0000
diff --git a/Demos/Device/Incomplete/Sideshow/Descriptors.c b/Demos/Device/Incomplete/Sideshow/Descriptors.c
index 8f4c7c532..4e3983c22 100644
--- a/Demos/Device/Incomplete/Sideshow/Descriptors.c
+++ b/Demos/Device/Incomplete/Sideshow/Descriptors.c
@@ -34,7 +34,7 @@ USB_Descriptor_Device_t PROGMEM DeviceDescriptor =
 {
 	Header:                 {Size: sizeof(USB_Descriptor_Device_t), Type: DTYPE_Device},
 		
-	USBSpecification:       VERSION_BCD(02.00),
+	USBSpecification:       VERSION_BCD(01.10),
 	Class:                  0x00,
 	SubClass:               0x00,
 	Protocol:               0x00,
diff --git a/Demos/Device/Incomplete/TestAndMeasurement/Descriptors.c b/Demos/Device/Incomplete/TestAndMeasurement/Descriptors.c
index 53c6a0193..0cb7852ab 100644
--- a/Demos/Device/Incomplete/TestAndMeasurement/Descriptors.c
+++ b/Demos/Device/Incomplete/TestAndMeasurement/Descriptors.c
@@ -59,7 +59,7 @@ USB_Descriptor_Device_t PROGMEM DeviceDescriptor =
 {
 	.Header                 = {.Size = sizeof(USB_Descriptor_Device_t), .Type = DTYPE_Device},
 
-	.USBSpecification       = VERSION_BCD(02.00),
+	.USBSpecification       = VERSION_BCD(01.10),
 	.Class                  = 0x00,
 	.SubClass               = 0x00,
 	.Protocol               = 0x00,
diff --git a/Demos/Device/LowLevel/AudioInput/Descriptors.c b/Demos/Device/LowLevel/AudioInput/Descriptors.c
index 307439611..ddcac155a 100644
--- a/Demos/Device/LowLevel/AudioInput/Descriptors.c
+++ b/Demos/Device/LowLevel/AudioInput/Descriptors.c
@@ -46,7 +46,7 @@ USB_Descriptor_Device_t PROGMEM DeviceDescriptor =
 {
 	.Header                 = {.Size = sizeof(USB_Descriptor_Device_t), .Type = DTYPE_Device},
 		
-	.USBSpecification       = VERSION_BCD(02.00),
+	.USBSpecification       = VERSION_BCD(01.10),
 	.Class                  = 0x00,
 	.SubClass               = 0x00,
 	.Protocol               = 0x00,
@@ -226,7 +226,7 @@ USB_Descriptor_Configuration_t PROGMEM ConfigurationDescriptor =
 			.Header                   = {.Size = sizeof(USB_Audio_StreamEndpoint_Spc_t), .Type = DTYPE_CSEndpoint},
 			.Subtype                  = DSUBTYPE_General,
 			
-			.Attributes               = 0x00,
+			.Attributes               = EP_ACCEPTS_SMALL_PACKETS,
 			
 			.LockDelayUnits           = 0x00,
 			.LockDelay                = 0x0000
diff --git a/Demos/Device/LowLevel/AudioOutput/Descriptors.c b/Demos/Device/LowLevel/AudioOutput/Descriptors.c
index 2d749fcd3..d6e8ef632 100644
--- a/Demos/Device/LowLevel/AudioOutput/Descriptors.c
+++ b/Demos/Device/LowLevel/AudioOutput/Descriptors.c
@@ -46,7 +46,7 @@ USB_Descriptor_Device_t PROGMEM DeviceDescriptor =
 {
 	.Header                 = {.Size = sizeof(USB_Descriptor_Device_t), .Type = DTYPE_Device},
 		
-	.USBSpecification       = VERSION_BCD(02.00),
+	.USBSpecification       = VERSION_BCD(01.10),
 	.Class                  = 0x00,
 	.SubClass               = 0x00,
 	.Protocol               = 0x00,
diff --git a/Demos/Device/LowLevel/MIDI/Descriptors.c b/Demos/Device/LowLevel/MIDI/Descriptors.c
index af52cba43..2d2b365aa 100644
--- a/Demos/Device/LowLevel/MIDI/Descriptors.c
+++ b/Demos/Device/LowLevel/MIDI/Descriptors.c
@@ -107,7 +107,7 @@ USB_Descriptor_Configuration_t PROGMEM ConfigurationDescriptor =
 			.Header                   = {.Size = sizeof(USB_Audio_Interface_AC_t), .Type = DTYPE_CSInterface},
 			.Subtype                  = DSUBTYPE_AudioHeader,
 			
-			.ACSpecification          = VERSION_BCD(01.00),
+			.AudioSpecification       = VERSION_BCD(01.00),
 			.TotalLength              = sizeof(USB_Audio_Interface_AC_t),
 			
 			.InCollection             = 1,
diff --git a/Demos/Device/LowLevel/MIDI/Descriptors.h b/Demos/Device/LowLevel/MIDI/Descriptors.h
index 5aebd8fdb..b364c1b62 100644
--- a/Demos/Device/LowLevel/MIDI/Descriptors.h
+++ b/Demos/Device/LowLevel/MIDI/Descriptors.h
@@ -79,7 +79,7 @@
 			USB_Descriptor_Header_t   Header; /**< Regular descriptor header containing the descriptor's type and length */
 			uint8_t                   Subtype; /**< Sub type value used to distinguish between audio class specific descriptors */
 
-			uint16_t                  ACSpecification; /**< Binary coded decimal value, indicating the supported Audio Class specification version */
+			uint16_t                  AudioSpecification; /**< Binary coded decimal value, indicating the supported Audio Class specification version */
 			uint16_t                  TotalLength; /**< Total length of the Audio class specific control descriptors, including this descriptor */
 			
 			uint8_t                   InCollection; /**< Total number of audio class interfaces within this device */
diff --git a/Demos/Device/LowLevel/Mouse/Descriptors.c b/Demos/Device/LowLevel/Mouse/Descriptors.c
index 70538fe5c..f85ff61eb 100644
--- a/Demos/Device/LowLevel/Mouse/Descriptors.c
+++ b/Demos/Device/LowLevel/Mouse/Descriptors.c
@@ -82,7 +82,7 @@ USB_Descriptor_Device_t PROGMEM DeviceDescriptor =
 {
 	.Header                 = {.Size = sizeof(USB_Descriptor_Device_t), .Type = DTYPE_Device},
 		
-	.USBSpecification       = VERSION_BCD(02.00),
+	.USBSpecification       = VERSION_BCD(01.10),
 	.Class                  = 0x00,
 	.SubClass               = 0x00,
 	.Protocol               = 0x00,
diff --git a/LUFA/Drivers/USB/Class/Common/Audio.h b/LUFA/Drivers/USB/Class/Common/Audio.h
index f4b784908..0b023b019 100644
--- a/LUFA/Drivers/USB/Class/Common/Audio.h
+++ b/LUFA/Drivers/USB/Class/Common/Audio.h
@@ -74,140 +74,140 @@
 		#endif
 		
 		/** Supported channel mask for an Audio class terminal descriptor. See the Audio class specification for more details. */
-		#define CHANNEL_LEFT_FRONT           (1 << 0)
+		#define AUDIO_CHANNEL_LEFT_FRONT           (1 << 0)
 
 		/** Supported channel mask for an Audio class terminal descriptor. See the Audio class specification for more details. */
-		#define CHANNEL_RIGHT_FRONT          (1 << 1)
+		#define AUDIO_CHANNEL_RIGHT_FRONT          (1 << 1)
 
 		/** Supported channel mask for an Audio class terminal descriptor. See the Audio class specification for more details. */
-		#define CHANNEL_CENTER_FRONT         (1 << 2)
+		#define AUDIO_CHANNEL_CENTER_FRONT         (1 << 2)
 
 		/** Supported channel mask for an Audio class terminal descriptor. See the Audio class specification for more details. */
-		#define CHANNEL_LOW_FREQ_ENHANCE     (1 << 3)
+		#define AUDIO_CHANNEL_LOW_FREQ_ENHANCE     (1 << 3)
 
 		/** Supported channel mask for an Audio class terminal descriptor. See the Audio class specification for more details. */
-		#define CHANNEL_LEFT_SURROUND        (1 << 4)
+		#define AUDIO_CHANNEL_LEFT_SURROUND        (1 << 4)
 
 		/** Supported channel mask for an Audio class terminal descriptor. See the Audio class specification for more details. */
-		#define CHANNEL_RIGHT_SURROUND       (1 << 5)
+		#define AUDIO_CHANNEL_RIGHT_SURROUND       (1 << 5)
 
 		/** Supported channel mask for an Audio class terminal descriptor. See the Audio class specification for more details. */
-		#define CHANNEL_LEFT_OF_CENTER       (1 << 6)
+		#define AUDIO_CHANNEL_LEFT_OF_CENTER       (1 << 6)
 
 		/** Supported channel mask for an Audio class terminal descriptor. See the Audio class specification for more details. */
-		#define CHANNEL_RIGHT_OF_CENTER      (1 << 7)
+		#define AUDIO_CHANNEL_RIGHT_OF_CENTER      (1 << 7)
 
 		/** Supported channel mask for an Audio class terminal descriptor. See the Audio class specification for more details. */
-		#define CHANNEL_SURROUND             (1 << 8)
+		#define AUDIO_CHANNEL_SURROUND             (1 << 8)
 
 		/** Supported channel mask for an Audio class terminal descriptor. See the Audio class specification for more details. */
-		#define CHANNEL_SIDE_LEFT            (1 << 9)
+		#define AUDIO_CHANNEL_SIDE_LEFT            (1 << 9)
 
 		/** Supported channel mask for an Audio class terminal descriptor. See the Audio class specification for more details. */
-		#define CHANNEL_SIDE_RIGHT           (1 << 10)
+		#define AUDIO_CHANNEL_SIDE_RIGHT           (1 << 10)
 
 		/** Supported channel mask for an Audio class terminal descriptor. See the Audio class specification for more details. */
-		#define CHANNEL_TOP                  (1 << 11)
+		#define AUDIO_CHANNEL_TOP                  (1 << 11)
 
 		/** Supported feature mask for an Audio class feature unit descriptor. See the Audio class specification for more details. */
-		#define FEATURE_MUTE                 (1 << 0)
+		#define AUDIO_FEATURE_MUTE                 (1 << 0)
 
 		/** Supported feature mask for an Audio class feature unit descriptor. See the Audio class specification for more details. */
-		#define FEATURE_VOLUME               (1 << 1)
+		#define AUDIO_FEATURE_VOLUME               (1 << 1)
 
 		/** Supported feature mask for an Audio class feature unit descriptor. See the Audio class specification for more details. */
-		#define FEATURE_BASS                 (1 << 2)
+		#define AUDIO_FEATURE_BASS                 (1 << 2)
 
 		/** Supported feature mask for an Audio class feature unit descriptor. See the Audio class specification for more details. */
-		#define FEATURE_MID                  (1 << 3)
+		#define AUDIO_FEATURE_MID                  (1 << 3)
 
 		/** Supported feature mask for an Audio class feature unit descriptor. See the Audio class specification for more details. */
-		#define FEATURE_TREBLE               (1 << 4)
+		#define AUDIO_FEATURE_TREBLE               (1 << 4)
 
 		/** Supported feature mask for an Audio class feature unit descriptor. See the Audio class specification for more details. */
-		#define FEATURE_GRAPHIC_EQUALIZER    (1 << 5)
+		#define AUDIO_FEATURE_GRAPHIC_EQUALIZER    (1 << 5)
 
 		/** Supported feature mask for an Audio class feature unit descriptor. See the Audio class specification for more details. */
-		#define FEATURE_AUTOMATIC_GAIN       (1 << 6)
+		#define AUDIO_FEATURE_AUTOMATIC_GAIN       (1 << 6)
 
 		/** Supported feature mask for an Audio class feature unit descriptor. See the Audio class specification for more details. */
-		#define FEATURE_DELAY                (1 << 7)
+		#define AUDIO_FEATURE_DELAY                (1 << 7)
 
 		/** Supported feature mask for an Audio class feature unit descriptor. See the Audio class specification for more details. */
-		#define FEATURE_BASS_BOOST           (1 << 8)
+		#define AUDIO_FEATURE_BASS_BOOST           (1 << 8)
 
 		/** Supported feature mask for an Audio class feature unit descriptor. See the Audio class specification for more details. */
-		#define FEATURE_BASS_LOUDNESS        (1 << 9)
+		#define AUDIO_FEATURE_BASS_LOUDNESS        (1 << 9)
 
 		/** Terminal type constant for an Audio class terminal descriptor. See the Audio class specification for more details. */		
-		#define TERMINAL_UNDEFINED           0x0100
+		#define AUDIO_TERMINAL_UNDEFINED           0x0100
 
 		/** Terminal type constant for an Audio class terminal descriptor. See the Audio class specification for more details. */		
-		#define TERMINAL_STREAMING           0x0101
+		#define AUDIO_TERMINAL_STREAMING           0x0101
 
 		/** Terminal type constant for an Audio class terminal descriptor. See the Audio class specification for more details. */		
-		#define TERMINAL_VENDOR              0x01FF
+		#define AUDIO_TERMINAL_VENDOR              0x01FF
 
 		/** Terminal type constant for an Audio class terminal descriptor. See the Audio class specification for more details. */		
-		#define TERMINAL_IN_UNDEFINED        0x0200
+		#define AUDIO_TERMINAL_IN_UNDEFINED        0x0200
 
 		/** Terminal type constant for an Audio class terminal descriptor. See the Audio class specification for more details. */		
-		#define TERMINAL_IN_MIC              0x0201
+		#define AUDIO_TERMINAL_IN_MIC              0x0201
 
 		/** Terminal type constant for an Audio class terminal descriptor. See the Audio class specification for more details. */		
-		#define TERMINAL_IN_DESKTOP_MIC      0x0202
+		#define AUDIO_TERMINAL_IN_DESKTOP_MIC      0x0202
 
 		/** Terminal type constant for an Audio class terminal descriptor. See the Audio class specification for more details. */		
-		#define TERMINAL_IN_PERSONAL_MIC     0x0203
+		#define AUDIO_TERMINAL_IN_PERSONAL_MIC     0x0203
 
 		/** Terminal type constant for an Audio class terminal descriptor. See the Audio class specification for more details. */		
-		#define TERMINAL_IN_OMNIDIR_MIC      0x0204
+		#define AUDIO_TERMINAL_IN_OMNIDIR_MIC      0x0204
 
 		/** Terminal type constant for an Audio class terminal descriptor. See the Audio class specification for more details. */		
-		#define TERMINAL_IN_MIC_ARRAY        0x0205
+		#define AUDIO_TERMINAL_IN_MIC_ARRAY        0x0205
 
 		/** Terminal type constant for an Audio class terminal descriptor. See the Audio class specification for more details. */		
-		#define TERMINAL_IN_PROCESSING_MIC   0x0206
+		#define AUDIO_TERMINAL_IN_PROCESSING_MIC   0x0206
 
 		/** Terminal type constant for an Audio class terminal descriptor. See the Audio class specification for more details. */		
-		#define TERMINAL_IN_OUT_UNDEFINED    0x0300
+		#define AUDIO_TERMINAL_IN_OUT_UNDEFINED    0x0300
 
 		/** Terminal type constant for an Audio class terminal descriptor. See the Audio class specification for more details. */		
-		#define TERMINAL_OUT_SPEAKER         0x0301
+		#define AUDIO_TERMINAL_OUT_SPEAKER         0x0301
 
 		/** Terminal type constant for an Audio class terminal descriptor. See the Audio class specification for more details. */		
-		#define TERMINAL_OUT_HEADPHONES      0x0302
+		#define AUDIO_TERMINAL_OUT_HEADPHONES      0x0302
 
 		/** Terminal type constant for an Audio class terminal descriptor. See the Audio class specification for more details. */		
-		#define TERMINAL_OUT_HEAD_MOUNTED    0x0303
+		#define AUDIO_TERMINAL_OUT_HEAD_MOUNTED    0x0303
 
 		/** Terminal type constant for an Audio class terminal descriptor. See the Audio class specification for more details. */		
-		#define TERMINAL_OUT_DESKTOP         0x0304
+		#define AUDIO_TERMINAL_OUT_DESKTOP         0x0304
 
 		/** Terminal type constant for an Audio class terminal descriptor. See the Audio class specification for more details. */		
-		#define TERMINAL_OUT_ROOM            0x0305
+		#define AUDIO_TERMINAL_OUT_ROOM            0x0305
 
 		/** Terminal type constant for an Audio class terminal descriptor. See the Audio class specification for more details. */		
-		#define TERMINAL_OUT_COMMUNICATION   0x0306
+		#define AUDIO_TERMINAL_OUT_COMMUNICATION   0x0306
 
 		/** Terminal type constant for an Audio class terminal descriptor. See the Audio class specification for more details. */		
-		#define TERMINAL_OUT_LOWFREQ         0x0307
+		#define AUDIO_TERMINAL_OUT_LOWFREQ         0x0307
 
-		/** Convenience macro, to fill a 24-bit AudioSampleFreq_t structure with the given sample rate as a 24-bit number.
+		/** Convenience macro to fill a 24-bit \ref USB_Audio_SampleFreq_t structure with the given sample rate as a 24-bit number.
 		 *
 		 *  \param[in] freq  Required audio sampling frequency in HZ
 		 */
-		#define AUDIO_SAMPLE_FREQ(freq)      {LowWord: ((uint32_t)freq & 0x00FFFF), HighByte: (((uint32_t)freq >> 16) & 0x0000FF)}
+		#define AUDIO_SAMPLE_FREQ(freq)           {((uint32_t)freq & 0x00FFFF), (((uint32_t)freq >> 16) & 0x0000FF)}
 		
 		/** Mask for the attributes parameter of an Audio class-specific Endpoint descriptor, indicating that the endpoint
 		 *  accepts only filled endpoint packets of audio samples.
 		 */
-		#define EP_ACCEPTS_ONLY_FULL_PACKETS (1 << 7)
+		#define AUDIO_EP_FULL_PACKETS_ONLY        (1 << 7)
 
 		/** Mask for the attributes parameter of an Audio class-specific Endpoint descriptor, indicating that the endpoint
 		 *  will accept partially filled endpoint packets of audio samples.
 		 */
-		#define EP_ACCEPTS_SMALL_PACKETS     (0 << 7)
+		#define AUDIO_EP_ACCEPTS_SMALL_PACKETS    (0 << 7)
 	
 	/* Enums: */
 		/** Audio class specific interface description subtypes, for the Audio Control interface. */
diff --git a/LUFA/Drivers/USB/Class/Common/RNDIS.h b/LUFA/Drivers/USB/Class/Common/RNDIS.h
index 98d41a2c4..b9d50f93c 100644
--- a/LUFA/Drivers/USB/Class/Common/RNDIS.h
+++ b/LUFA/Drivers/USB/Class/Common/RNDIS.h
@@ -83,9 +83,6 @@
 		/** Maximum size in bytes of an Ethernet frame according to the Ethernet standard. */
 		#define ETHERNET_FRAME_SIZE_MAX               1500
 		
-		/** Notification request value for a RNDIS Response Available notification. */
-		#define NOTIF_ResponseAvailable               1
-		
 	/* Enums: */
 		/** Enum for the RNDIS class specific control requests that can be issued by the USB bus host. */
 		enum RNDIS_ClassRequests_t
@@ -102,6 +99,12 @@
 			RNDIS_Data_Initialized = 2, /**< Adapter currently initialized and ready for data transfers. */
 		};
 
+		/** Enum for the RNDIS class specific notification requests that can be issued by a RNDIS device to a host. */
+		enum RNDIS_ClassNotifications_t
+		{
+			RNDIS_NOTIF_ResponseAvailable             = 0x01, /**< Notification request value for a RNDIS Response Available notification. */
+		};
+
 		/** Enum for the NDIS hardware states. */
 		enum NDIS_Hardware_Status_t
 		{
diff --git a/LUFA/Drivers/USB/Class/Device/RNDIS.c b/LUFA/Drivers/USB/Class/Device/RNDIS.c
index 394827ed2..3be2ab41e 100644
--- a/LUFA/Drivers/USB/Class/Device/RNDIS.c
+++ b/LUFA/Drivers/USB/Class/Device/RNDIS.c
@@ -152,7 +152,7 @@ void RNDIS_Device_USBTask(USB_ClassInfo_RNDIS_Device_t* const RNDISInterfaceInfo
 		USB_Request_Header_t Notification = (USB_Request_Header_t)
 			{
 				.bmRequestType = (REQDIR_DEVICETOHOST | REQTYPE_CLASS | REQREC_INTERFACE),
-				.bRequest      = NOTIF_ResponseAvailable,
+				.bRequest      = RNDIS_NOTIF_ResponseAvailable,
 				.wValue        = 0,
 				.wIndex        = 0,
 				.wLength       = 0,
diff --git a/LUFA/Drivers/USB/Class/Host/CDC.h b/LUFA/Drivers/USB/Class/Host/CDC.h
index d71c1671f..848dd361a 100644
--- a/LUFA/Drivers/USB/Class/Host/CDC.h
+++ b/LUFA/Drivers/USB/Class/Host/CDC.h
@@ -139,7 +139,7 @@
 			
 		/* Enums: */
 			/** Enum for the possible error codes returned by the \ref CDC_Host_ConfigurePipes() function. */
-			enum CDCHost_EnumerationFailure_ErrorCodes_t
+			enum CDC_Host_EnumerationFailure_ErrorCodes_t
 			{
 				CDC_ENUMERROR_NoError                    = 0, /**< Configuration Descriptor was processed successfully. */
 				CDC_ENUMERROR_InvalidConfigDescriptor    = 1, /**< The device returned an invalid Configuration Descriptor. */
@@ -165,7 +165,7 @@
 			 *  \param[in]     ConfigDescriptorSize    Length of the attached device's Configuration Descriptor.
 			 *  \param[in]     DeviceConfigDescriptor  Pointer to a buffer containing the attached device's Configuration Descriptor.
 			 *
 			 *  \return A value from the \ref CDCHost_EnumerationFailure_ErrorCodes_t enum.
 			 */
 			uint8_t CDC_Host_ConfigurePipes(USB_ClassInfo_CDC_Host_t* const CDCInterfaceInfo,
 			                                uint16_t ConfigDescriptorSize,
@@ -165,7 +165,7 @@
 			 *  \param[in]     DeviceConfigDescriptor  Pointer to a buffer containing the attached device's Configuration Descriptor.
 			 *
-			 *  \return A value from the \ref CDCHost_EnumerationFailure_ErrorCodes_t enum.
+			 *  \return A value from the \ref CDC_Host_EnumerationFailure_ErrorCodes_t enum.
 			 */
 			uint8_t CDC_Host_ConfigurePipes(USB_ClassInfo_CDC_Host_t* const CDCInterfaceInfo,
diff --git a/LUFA/Drivers/USB/Class/Host/HID.h b/LUFA/Drivers/USB/Class/Host/HID.h
index 914d43278..bbc8f5d12 100644
--- a/LUFA/Drivers/USB/Class/Host/HID.h
+++ b/LUFA/Drivers/USB/Class/Host/HID.h
@@ -135,7 +135,7 @@
 
 		/* Enums: */
 			/** Enum for the possible error codes returned by the \ref HID_Host_ConfigurePipes() function. */
-			enum HIDHost_EnumerationFailure_ErrorCodes_t
+			enum HID_Host_EnumerationFailure_ErrorCodes_t
 			{
 				HID_ENUMERROR_NoError                    = 0, /**< Configuration Descriptor was processed successfully. */
 				HID_ENUMERROR_InvalidConfigDescriptor    = 1, /**< The device returned an invalid Configuration Descriptor. */
@@ -158,7 +158,7 @@
 			 *  \param[in]     ConfigDescriptorSize    Length of the attached device's Configuration Descriptor.
 			 *  \param[in]     DeviceConfigDescriptor  Pointer to a buffer containing the attached device's Configuration Descriptor.
 			 *
 			 *  \return A value from the \ref HIDHost_EnumerationFailure_ErrorCodes_t enum.
 			 */
 			uint8_t HID_Host_ConfigurePipes(USB_ClassInfo_HID_Host_t* const HIDInterfaceInfo,
 			                                uint16_t ConfigDescriptorSize,
@@ -158,7 +158,7 @@
 			 *  \param[in]     DeviceConfigDescriptor  Pointer to a buffer containing the attached device's Configuration Descriptor.
 			 *
-			 *  \return A value from the \ref HIDHost_EnumerationFailure_ErrorCodes_t enum.
+			 *  \return A value from the \ref HID_Host_EnumerationFailure_ErrorCodes_t enum.
 			 */
 			uint8_t HID_Host_ConfigurePipes(USB_ClassInfo_HID_Host_t* const HIDInterfaceInfo,
diff --git a/LUFA/Drivers/USB/Class/Host/MIDI.h b/LUFA/Drivers/USB/Class/Host/MIDI.h
index 2cfb56e57..d5cf5829e 100644
--- a/LUFA/Drivers/USB/Class/Host/MIDI.h
+++ b/LUFA/Drivers/USB/Class/Host/MIDI.h
@@ -104,7 +104,7 @@
 			
 		/* Enums: */
 			/** Enum for the possible error codes returned by the \ref MIDI_Host_ConfigurePipes() function. */
-			enum MIDIHost_EnumerationFailure_ErrorCodes_t
+			enum MIDI_Host_EnumerationFailure_ErrorCodes_t
 			{
 				MIDI_ENUMERROR_NoError                    = 0, /**< Configuration Descriptor was processed successfully. */
 				MIDI_ENUMERROR_InvalidConfigDescriptor    = 1, /**< The device returned an invalid Configuration Descriptor. */
@@ -123,7 +123,7 @@
 			 *  \param[in]     ConfigDescriptorSize    Length of the attached device's Configuration Descriptor.
 			 *  \param[in]     DeviceConfigDescriptor  Pointer to a buffer containing the attached device's Configuration Descriptor.
 			 *
 			 *  \return A value from the \ref MIDIHost_EnumerationFailure_ErrorCodes_t enum.
 			 */
 			uint8_t MIDI_Host_ConfigurePipes(USB_ClassInfo_MIDI_Host_t* const MIDIInterfaceInfo,
 			                                 uint16_t ConfigDescriptorSize,
@@ -123,7 +123,7 @@
 			 *  \param[in]     DeviceConfigDescriptor  Pointer to a buffer containing the attached device's Configuration Descriptor.
 			 *
-			 *  \return A value from the \ref MIDIHost_EnumerationFailure_ErrorCodes_t enum.
+			 *  \return A value from the \ref MIDI_Host_EnumerationFailure_ErrorCodes_t enum.
 			 */
 			uint8_t MIDI_Host_ConfigurePipes(USB_ClassInfo_MIDI_Host_t* const MIDIInterfaceInfo,
diff --git a/LUFA/Drivers/USB/Class/Host/MassStorage.h b/LUFA/Drivers/USB/Class/Host/MassStorage.h
index a6b32c791..bfbe6cdb7 100644
--- a/LUFA/Drivers/USB/Class/Host/MassStorage.h
+++ b/LUFA/Drivers/USB/Class/Host/MassStorage.h
@@ -122,7 +122,7 @@
 			} SCSI_Capacity_t;
 
 		/* Enums: */
-			enum MSHost_EnumerationFailure_ErrorCodes_t
+			enum MS_Host_EnumerationFailure_ErrorCodes_t
 			{
 				MS_ENUMERROR_NoError                    = 0, /**< Configuration Descriptor was processed successfully. */
 				MS_ENUMERROR_InvalidConfigDescriptor    = 1, /**< The device returned an invalid Configuration Descriptor. */
@@ -141,7 +141,7 @@
 			 *  \param[in]     ConfigDescriptorSize    Length of the attached device's Configuration Descriptor.
 			 *  \param[in]     DeviceConfigDescriptor  Pointer to a buffer containing the attached device's Configuration Descriptor.
 			 *
 			 *  \return A value from the \ref MSHost_EnumerationFailure_ErrorCodes_t enum.
 			 */
 			uint8_t MS_Host_ConfigurePipes(USB_ClassInfo_MS_Host_t* const MSInterfaceInfo,
 			                               uint16_t ConfigDescriptorSize,
@@ -141,7 +141,7 @@
 			 *  \param[in]     DeviceConfigDescriptor  Pointer to a buffer containing the attached device's Configuration Descriptor.
 			 *
-			 *  \return A value from the \ref MSHost_EnumerationFailure_ErrorCodes_t enum.
+			 *  \return A value from the \ref MS_Host_EnumerationFailure_ErrorCodes_t enum.
 			 */
 			uint8_t MS_Host_ConfigurePipes(USB_ClassInfo_MS_Host_t* const MSInterfaceInfo,
diff --git a/LUFA/Drivers/USB/Class/Host/Printer.h b/LUFA/Drivers/USB/Class/Host/Printer.h
index 01f88b9a2..37216081b 100644
--- a/LUFA/Drivers/USB/Class/Host/Printer.h
+++ b/LUFA/Drivers/USB/Class/Host/Printer.h
@@ -105,7 +105,7 @@
 			} USB_ClassInfo_PRNT_Host_t;
 
 		/* Enums: */
-			enum PRNTHost_EnumerationFailure_ErrorCodes_t
+			enum PRNT_Host_EnumerationFailure_ErrorCodes_t
 			{
 				PRNT_ENUMERROR_NoError                    = 0, /**< Configuration Descriptor was processed successfully. */
 				PRNT_ENUMERROR_InvalidConfigDescriptor    = 1, /**< The device returned an invalid Configuration Descriptor. */
@@ -132,7 +132,7 @@
 			 *  \param[in]     ConfigDescriptorSize    Length of the attached device's Configuration Descriptor.
 			 *  \param[in]     DeviceConfigDescriptor  Pointer to a buffer containing the attached device's Configuration Descriptor.
 			 *
 			 *  \return A value from the \ref PRNTHost_EnumerationFailure_ErrorCodes_t enum.
 			 */
 			uint8_t PRNT_Host_ConfigurePipes(USB_ClassInfo_PRNT_Host_t* const PRNTInterfaceInfo,
 			                                 uint16_t ConfigDescriptorSize,
@@ -132,7 +132,7 @@
 			 *  \param[in]     DeviceConfigDescriptor  Pointer to a buffer containing the attached device's Configuration Descriptor.
 			 *
-			 *  \return A value from the \ref PRNTHost_EnumerationFailure_ErrorCodes_t enum.
+			 *  \return A value from the \ref PRNT_Host_EnumerationFailure_ErrorCodes_t enum.
 			 */
 			uint8_t PRNT_Host_ConfigurePipes(USB_ClassInfo_PRNT_Host_t* const PRNTInterfaceInfo,
diff --git a/LUFA/Drivers/USB/Class/Host/RNDIS.h b/LUFA/Drivers/USB/Class/Host/RNDIS.h
index b1518ffed..df99824bd 100644
--- a/LUFA/Drivers/USB/Class/Host/RNDIS.h
+++ b/LUFA/Drivers/USB/Class/Host/RNDIS.h
@@ -119,7 +119,7 @@
 			
 		/* Enums: */
 			/** Enum for the possible error codes returned by the \ref RNDIS_Host_ConfigurePipes() function. */
-			enum RNDISHost_EnumerationFailure_ErrorCodes_t
+			enum RNDIS_Host_EnumerationFailure_ErrorCodes_t
 			{
 				RNDIS_ENUMERROR_NoError                    = 0, /**< Configuration Descriptor was processed successfully. */
 				RNDIS_ENUMERROR_InvalidConfigDescriptor    = 1, /**< The device returned an invalid Configuration Descriptor. */
@@ -142,7 +142,7 @@
 			 *  \param[in]     ConfigDescriptorSize    Length of the attached device's Configuration Descriptor.
 			 *  \param[in]     DeviceConfigDescriptor  Pointer to a buffer containing the attached device's Configuration Descriptor.
 			 *
 			 *  \return A value from the \ref RNDISHost_EnumerationFailure_ErrorCodes_t enum.
 			 */
 			uint8_t RNDIS_Host_ConfigurePipes(USB_ClassInfo_RNDIS_Host_t* const RNDISInterfaceInfo,
 			                                  uint16_t ConfigDescriptorSize,
@@ -142,7 +142,7 @@
 			 *  \param[in]     DeviceConfigDescriptor  Pointer to a buffer containing the attached device's Configuration Descriptor.
 			 *
-			 *  \return A value from the \ref RNDISHost_EnumerationFailure_ErrorCodes_t enum.
+			 *  \return A value from the \ref RNDIS_Host_EnumerationFailure_ErrorCodes_t enum.
 			 */
 			uint8_t RNDIS_Host_ConfigurePipes(USB_ClassInfo_RNDIS_Host_t* const RNDISInterfaceInfo,
diff --git a/LUFA/Drivers/USB/Class/Host/StillImage.h b/LUFA/Drivers/USB/Class/Host/StillImage.h
index c215f1072..020f03003 100644
--- a/LUFA/Drivers/USB/Class/Host/StillImage.h
+++ b/LUFA/Drivers/USB/Class/Host/StillImage.h
@@ -115,7 +115,7 @@
 	
 		/* Enums: */
 			/** Enum for the possible error codes returned by the \ref SI_Host_ConfigurePipes() function. */
-			enum SIHost_EnumerationFailure_ErrorCodes_t
+			enum SI_Host_EnumerationFailure_ErrorCodes_t
 			{
 				SI_ENUMERROR_NoError                    = 0, /**< Configuration Descriptor was processed successfully. */
 				SI_ENUMERROR_InvalidConfigDescriptor    = 1, /**< The device returned an invalid Configuration Descriptor. */
@@ -138,7 +138,7 @@
 			 *  \param[in]     ConfigDescriptorSize    Length of the attached device's Configuration Descriptor.
 			 *  \param[in]     DeviceConfigDescriptor  Pointer to a buffer containing the attached device's Configuration Descriptor.
 			 *
 			 *  \return A value from the \ref SIHost_EnumerationFailure_ErrorCodes_t enum.
 			 */
 			uint8_t SI_Host_ConfigurePipes(USB_ClassInfo_SI_Host_t* const SIInterfaceInfo,
 			                               uint16_t ConfigDescriptorSize,
@@ -138,7 +138,7 @@
 			 *  \param[in]     DeviceConfigDescriptor  Pointer to a buffer containing the attached device's Configuration Descriptor.
 			 *
-			 *  \return A value from the \ref SIHost_EnumerationFailure_ErrorCodes_t enum.
+			 *  \return A value from the \ref SI_Host_EnumerationFailure_ErrorCodes_t enum.
 			 */
 			uint8_t SI_Host_ConfigurePipes(USB_ClassInfo_SI_Host_t* const SIInterfaceInfo,
-- 
GitLab